@@ -7,6 +7,7 @@ from .artifact import Artifact, save_response_to
 from .input import PendingInputAction
 from .item import Item
 from .mix import DeletionMixIn, DescriptionMixIn
+from .report import TestReport
 
 
 class Build(Item, DescriptionMixIn, DeletionMixIn):
@@ -55,6 +56,10 @@ class Build(Item, DescriptionMixIn, DeletionMixIn):
         job_name = self.jenkins._url2name(re.sub(r'\w+[/]?$', '', self.url))
         return self.jenkins.get_job(job_name)
 
+    def get_test_report(self):
+        tr = TestReport(self.jenkins, f'{self.url}testReport')
+        return tr if tr.exists() else None
+
 
 class WorkflowRun(Build):
 
